==> webauthn4j-core-0.24.0.RELEASE-sources.jar: com/webauthn4j/data/extension/client/CredentialProtectionExtensionClientInput.java <==
package com.webauthn4j.data.extension.client;

import com.webauthn4j.data.extension.CredentialProtectionPolicy;
import com.webauthn4j.validator.exception.ConstraintViolationException;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;


public class CredentialProtectionExtensionClientInput implements RegistrationExtensionClientInput {

    public static final String ID = "credProtect";
    public static final String KEY_CREDENTIAL_PROTECTION_POLICY = "credentialProtectionPolicy";
    public static final String KEY_ENFORCE_CREDENTIAL_PROTECTION_POLICY = "enforceCredentialProtectionPolicy";

    private final CredentialProtectionPolicy credentialProtectionPolicy;
    private final Boolean enforceCredentialProtectionPolicy;

    public CredentialProtectionExtensionClientInput(
            @Nullable CredentialProtectionPolicy credentialProtectionPolicy,
            @Nullable Boolean enforceCredentialProtectionPolicy) {
        this.credentialProtectionPolicy = credentialProtectionPolicy;
        this.enforceCredentialProtectionPolicy = enforceCredentialProtectionPolicy;
    }

    public CredentialProtectionExtensionClientInput(@Nullable CredentialProtectionPolicy credentialProtectionPolicy) {
        this(credentialProtectionPolicy, null);
    }

    @Override
    public @NotNull String getIdentifier() {
        return ID;
    }

    public @Nullable CredentialProtectionPolicy getCredentialProtectionPolicy() {
        return credentialProtectionPolicy;
    }

    public @Nullable Boolean getEnforceCredentialProtectionPolicy() {
        return enforceCredentialProtectionPolicy;
    }

    @Override
    public @Nullable Object getValue(@NotNull String key) {
        switch (key) {
            case KEY_CREDENTIAL_PROTECTION_POLICY:
                return credentialProtectionPolicy;
            case KEY_ENFORCE_CREDENTIAL_PROTECTION_POLICY:
                return enforceCredentialProtectionPolicy;
            default:
                throw new IllegalArgumentException(String.format("%s is not valid key.", key));
        }
    }

    @Override
    public void validate() {
        if (credentialProtectionPolicy == null) {
            throw new ConstraintViolationException("credentialProtectionPolicy must not be null.");
        }
    }

}

==> webauthn4j-core-0.28.0.RELEASE-sources.jar: com/webauthn4j/data/extension/client/CredentialProtectionExtensionClientInput.java <==
package com.webauthn4j.data.extension.client;

import com.webauthn4j.data.extension.CredentialProtectionPolicy;
import com.webauthn4j.verifier.exception.ConstraintViolationException;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;


public class CredentialProtectionExtensionClientInput implements RegistrationExtensionClientInput {

    public static final String ID = "credProtect";
    public static final String KEY_CREDENTIAL_PROTECTION_POLICY = "credentialProtectionPolicy";
    public static final String KEY_ENFORCE_CREDENTIAL_PROTECTION_POLICY = "enforceCredentialProtectionPolicy";

    private final CredentialProtectionPolicy credentialProtectionPolicy;
    private final Boolean enforceCredentialProtectionPolicy;

    public CredentialProtectionExtensionClientInput(
            @Nullable CredentialProtectionPolicy credentialProtectionPolicy,
            @Nullable Boolean enforceCredentialProtectionPolicy) {
        this.credentialProtectionPolicy = credentialProtectionPolicy;
        this.enforceCredentialProtectionPolicy = enforceCredentialProtectionPolicy;
    }

    public CredentialProtectionExtensionClientInput(@Nullable CredentialProtectionPolicy credentialProtectionPolicy) {
        this(credentialProtectionPolicy, null);
    }

    @Override
    public @NotNull String getIdentifier() {
        return ID;
    }

    public @Nullable CredentialProtectionPolicy getCredentialProtectionPolicy() {
        return credentialProtectionPolicy;
    }

    public @Nullable Boolean getEnforceCredentialProtectionPolicy() {
        return enforceCredentialProtectionPolicy;
    }

    @Override
    public @Nullable Object getValue(@NotNull String key) {
        switch (key) {
            case KEY_CREDENTIAL_PROTECTION_POLICY:
                return credentialProtectionPolicy;
            case KEY_ENFORCE_CREDENTIAL_PROTECTION_POLICY:
                return enforceCredentialProtectionPolicy;
            default:
                throw new IllegalArgumentException(String.format("%s is not valid key.", key));
        }
    }

    @Override
    public void validate() {
        if (credentialProtectionPolicy == null) {
            throw new ConstraintViolationException("credentialProtectionPolicy must not be null.");
        }
    }

}
